@@ -43,7 +43,7 @@ use base qw{ PPIx::Regexp::Token::GroupType };
 
 use PPIx::Regexp::Constant qw{ @CARP_NOT };
 
-our $VERSION = '0.086_01';
+our $VERSION = '0.087_01';
 
 sub __match_setup {
     my ( undef, $tokenizer ) = @_;	# Invocant unused
@@ -65,10 +65,11 @@ use constant DEF	=> {
 	expl	=> 'Evaluate code. Always matches.',
 	intro	=> '5.005',
     },
-    '**'	=> {
-	expl	=> 'Evaluate code, use as regexp at this point. Optimized.',
-	intro	=> '5.037008',
-    },
+#   Removed in 5.37.9.
+#   '**'	=> {
+#	expl	=> 'Evaluate code, use as regexp at this point. Optimized.',
+#	intro	=> '5.037008',
+#   },
     '*'		=> {
 	expl	=> 'Evaluate code. Always matches. Optimized.',
 	intro	=> '5.037008',
